@@ -20,15 +20,8 @@ from enum import IntEnum
 
 DBUS_NAME = "org.freedesktop.Avahi"
 DBUS_INTERFACE_SERVER = DBUS_NAME + ".Server"
-DBUS_PATH_SERVER = "/"
 DBUS_INTERFACE_ENTRY_GROUP = DBUS_NAME + ".EntryGroup"
 DBUS_INTERFACE_DOMAIN_BROWSER = DBUS_NAME + ".DomainBrowser"
-DBUS_INTERFACE_SERVICE_TYPE_BROWSER = DBUS_NAME + ".ServiceTypeBrowser"
-DBUS_INTERFACE_SERVICE_BROWSER = DBUS_NAME + ".ServiceBrowser"
-DBUS_INTERFACE_ADDRESS_RESOLVER = DBUS_NAME + ".AddressResolver"
-DBUS_INTERFACE_HOST_NAME_RESOLVER = DBUS_NAME + ".HostNameResolver"
-DBUS_INTERFACE_SERVICE_RESOLVER = DBUS_NAME + ".ServiceResolver"
-DBUS_INTERFACE_RECORD_BROWSER = DBUS_NAME + ".RecordBrowser"
 
 
 class ServerState(IntEnum):
@@ -40,7 +33,7 @@ class ServerState(IntEnum):
 
 
 class EntryGroup(IntEnum):
-    UNCOMMITED = 0
+    UNCOMMITTED = 0
     REGISTERING = 1
     ESTABLISHED = 2
     COLLISION = 3
